pub struct PluginInitializeRequest {
pub downstream: Option<String>,
pub plugin_type: PluginType,
pub seed: u64,
pub log_configuration: PluginLogConfiguration,
pub log_channel: IpcSender<LogRecord>,
}Expand description
Plugin initialization request. See SimulatorToPlugin::Initialize.
Fields
downstream: Option<String>Gatestream endpoint for the downstream plugin to connect to.
Must be specified for frontends and operators, must not be specified for backends.
plugin_type: PluginTypeThe expected plugin type.
seed: u64Random seed.
log_configuration: PluginLogConfigurationConfiguration for the logging subsystem of the plugin.
log_channel: IpcSender<LogRecord>Sender side of the log channel. Can be used by a Plugin to send log records to the simulator.