pub struct PluginLogConfiguration {
pub name: String,
pub verbosity: LoglevelFilter,
pub tee_files: Vec<TeeFileConfiguration>,
}Expand description
Configuration structure for the plugin logging system.
Fields
name: StringInstance name of the plugin used to identify it in log messages.
verbosity: LoglevelFilterSpecifies the verbosity of the messages sent to DQCsim.
tee_files: Vec<TeeFileConfiguration>Specifies the tee file configurations for this plugin.
Implementations
Sourceimpl PluginLogConfiguration
impl PluginLogConfiguration
Sourcepub fn new(
name: impl Into<String>,
verbosity: LoglevelFilter,
) -> PluginLogConfiguration
pub fn new( name: impl Into<String>, verbosity: LoglevelFilter, ) -> PluginLogConfiguration
Returns a new PluginLogConfiguration. PluginLogConfigurations constructed using this method have no tee files setup by default.