pub struct PluginReproduction {
pub name: String,
pub executable: PathBuf,
pub script: Option<PathBuf>,
pub functional: PluginProcessFunctionalConfiguration,
}Expand description
The contents of a plugin configuration in a reproduction file.
Fields
name: StringName of the plugin, used to refer to the plugin by the log system.
executable: PathBufThe executable filename of the plugin.
script: Option<PathBuf>If specified, the executable is expected to be an interpreter, which is to execute the specified script file. If not specified, the executable is a native plugin.
functional: PluginProcessFunctionalConfigurationThe functional configuration of the plugin, i.e. the options configuring how the plugin behaves (besides the specification).